@@ -7,17 +7,19 @@
 #'
 #' @return plots
 #' 
+#' @importFrom stats density
+#' 
 #' @export
 #' 
 #' @examples
 #' 
 #' \dontrun{
 #' 
-#' dt <- potato
+#' library(inti)
 #' 
-#' lm <- aov(stemdw ~ bloque + geno*treat, dt)
+#' lm <- aov(stemdw ~ bloque + geno*treat, data = potato)
 #' 
-#' #lm <- lme4::lmer(stemdw ~ bloque + (1|geno:treat), dt)
+#' # lm <- potato %>% lme4::lmer(stemdw ~ (1|bloque) + geno*treat, data = .)
 #'  
 #' plot(lm, which = 1)
 #' plot_diag(lm)[3]
@@ -34,7 +36,9 @@
 #' }
 #' 
 
-plot_diag <- function( model, title = NA) {
+plot_diag <- function(model, title = NA) {
+  
+  # model  <-  potato %>% lme4::lmer(stemdw ~ (1|bloque) + geno*treat, data = .)
   
   stopifnot(class(model) %in% c("lm", "aov", "lmerMod"))
   
@@ -52,7 +56,7 @@ plot_diag <- function( model, title = NA) {
   
   # Histogram
   p1 <- ggplot(dt , aes(.data$.resid)) +
-    geom_histogram(aes_string(y = "..density..", fill = "..count.."), 
+    geom_histogram(aes(y = ggplot2::after_stat(density)), 
                    color = "black", fill = "grey82", bins = 30) + 
     stat_function(fun = stats::dnorm, color = "blue", args = list(mean = 0, sd = sd(dt$.resid))) +
     theme_bw() +
@@ -96,14 +100,13 @@ plot_diag <- function( model, title = NA) {
          , subtitle = "Homoscedasticity" 
          )
   
-  p5 <-ggplot(dt, aes(stats::hatvalues(model), .data$.resid)) + 
+  p5 <- ggplot(dt, aes(stats::hatvalues(model), .data$.resid)) + 
     stat_smooth(method="loess", na.rm=TRUE) +
     xlab("Leverage")+ylab("Standardized Residuals") +
     ggtitle("Residual vs Leverage Plot") + 
     scale_size_continuous("Cook's Distance", range=c(1,5)) + 
     theme_bw() + theme(legend.position="bottom")
   
-  
   return(list(histogram = p1
               , qqplot = p2
               , residual = p3
