@@ -3,8 +3,8 @@
 #' Multivariate analysis for PCA and HCPC
 #'
 #' @param data Field book data.
-#' @param last_factor The last factor in your fieldbook.
-#' @param variables Variables to be use in the analysis.
+#' @param last_factor The last factor in your fieldbook  [string: NULL].
+#' @param variables Variables to be use in the analysis  [string: NULL].
 #' @param summary_by Variables for group the analysis.
 #' @param groups Groups for color in PCA.
 #'
@@ -15,19 +15,37 @@
 #'
 #' @return result and plots
 #'
-#' @import dplyr
-#' @importFrom FactoMineR HCPC PCA
-#' @importFrom tibble column_to_rownames
-#' @importFrom tidyr unite
-#'
 #' @export
+#' 
+#' @examples
+#' 
+#' \dontrun{
 #'
+#' library(inti)
+#' 
+#' fb <- inti::potato 
+#' 
+#' mv <- yupana_mvr(data = fb
+#'                  , last_factor = "geno"
+#'                  , summary_by = c("geno", "treat")
+#'                  , groups = "treat"
+#'                  , variables = c("all")
+#'                  #, variables = c("wue", "twue")
+#'                  )
+#'                  
+#' mv$plot[1] 
+#' 
+#' mv$data
+#' 
+#' 
+#' }
+#' 
 
 yupana_mvr <- function(data
                        , last_factor = NULL
                        , summary_by = NULL
                        , groups = NULL
-                       , variables = NA
+                       , variables = NULL
                        ) {
   
   where <- NULL
@@ -37,24 +55,31 @@ yupana_mvr <- function(data
   
   groups <- if(is.null(groups)) summary_by[1] else groups
   
+  variables <- if("all" %in% variables | all(is.null(variables))) { NULL } else {variables}
+  
   fb <- data %>% 
-    {if(!is.null(last_factor)) 
-      mutate(.data = ., across(c(1:{{last_factor}}), as.factor)) else .} %>% 
-    {if(!is.null(last_factor)) 
-      mutate(.data = ., across(!c(1:{{last_factor}}), as.numeric)) else .} %>%
-    select(where(~!all(is.na(.)))) %>%
-    {if( "all" %in% variables || is.na(variables) )
-      select(.data = ., {{summary_by}}, where(is.numeric)) else
-      select(.data = ., {{summary_by}}, {{variables}}) 
-        } %>%
-    group_by(across({{summary_by}})) %>%
-    summarise(across(everything(),  ~ mean(., na.rm = TRUE) ))  %>%
-    ungroup() %>% 
-    unite("rnames", {{summary_by}} , sep = "-", remove = FALSE) %>%
-    column_to_rownames("rnames") %>% 
+    {
+      if(!is.null(last_factor) & all(!is.null(variables)) ) {
+        dplyr::select(.data = ., c(1:{{last_factor}}), {{variables}})
+      } else .
+      } %>%
+    dplyr::mutate(.data = ., across(c(1:{{last_factor}}), as.factor)) %>% 
+    dplyr::mutate(.data = ., across(!c(1:{{last_factor}}), as.numeric)) %>% 
+    dplyr::group_by(across({{summary_by}})) %>%
+    dplyr::summarise(across(everything(),  ~ mean(., na.rm = TRUE) ))  %>%
+    dplyr::ungroup() %>% 
+    tidyr::unite("rnames", {{summary_by}} , sep = "-", remove = FALSE) %>%
+    tibble::column_to_rownames("rnames") %>% 
+    dplyr::select(where(~!all(is.na(.)))) %>%
     as.data.frame()
   
-  # str(fb)
+# condition ---------------------------------------------------------------
+
+  varnum <- fb %>% 
+    dplyr::select(!c(1:tail({{summary_by}}, n = 1))) %>% 
+    ncol()
+  
+  if(varnum <= 1) stop("Select at least two (2) variables")  
   
 # parameters --------------------------------------------------------------
 # -------------------------------------------------------------------------
@@ -71,7 +96,7 @@ yupana_mvr <- function(data
 # condtions ---------------------------------------------------------------
 
   n <- fb %>%
-    select(par$quali)  %>% 
+    dplyr::select(par$quali)  %>% 
     as.list() %>% 
     purrr::map(discard, is.na) %>% 
     lengths() %>% 
@@ -83,8 +108,8 @@ yupana_mvr <- function(data
 # -------------------------------------------------------------------------
   
   pca_info <- fb %>%
-    select(where(~ length(unique(.)) > 1)) %>%  # drop variables without variation
-    PCA(X = .
+    dplyr::select(where(~length(unique(.)) > 1)) %>%  # drop variables without variation
+    FactoMineR::PCA(X = .
         , scale.unit = T
         , quali.sup = quali_ncol
         , graph = FALSE
