@@ -1,10 +1,10 @@
 # -------------------------------------------------------------------------
-# tarpuy ------------------------------------------------------------------
+# Tarpuy ------------------------------------------------------------------
 # -------------------------------------------------------------------------
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/tarpuy/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2023-10-26
+#> date .: 2024-02-05
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -220,11 +220,11 @@ shinyServer(function(input, output, session) {
   plex <- reactive({
     
     plex <- tarpuy_plex(data = NULL
-                         , idea = input$plex_idea
-                         , goal = input$plex_goal
+                         , title = input$plex_title
+                         , objectives = input$plex_objectives
                          , hypothesis = input$plex_hypothesis
                          , rationale = input$plex_rationale
-                         , objectives = input$plex_objectives
+                         , references = input$plex_references
                          , plan = input$plex_plan
                          , institutions = input$plex_institutions
                          , researchers = input$plex_researchers
@@ -238,8 +238,9 @@ shinyServer(function(input, output, session) {
                          , about = input$plex_about
                          , fieldbook = input$plex_fieldbook
                          , album = input$plex_album
-                         , github = input$plex_github
-                         , gdocs = input$plex_gdocs
+                         , project = input$plex_project
+                         , repository = input$plex_repository
+                         , manuscript = input$plex_manuscript
                          , nfactor = input$plex_nfactors
                          , design = input$plex_design
                          , rep = input$plex_rep
@@ -736,19 +737,32 @@ connection_sheet_preview <- reactive({
   
   url <- info$spreadsheet_url
   
-  id <- if(input$connection_sheet_preview == "Field Book") {
+  # id <- if(input$connection_sheet_preview == "Field-Book") {
+  # 
+  #   info$sheets %>%
+  #     filter(name %in% input$connection_sheet_fieldbook) %>%
+  #     pluck("id")
+  #   
+  # } else if (input$connection_sheet_preview == "Traits")  {
+  #   
+  #   info$sheets %>%
+  #     filter(name %in% input$connection_sheet_traits) %>%
+  #     pluck("id")
+  #   
+  # }
   
-    info$sheets %>%
-      filter(name %in% input$connection_sheet_fieldbook) %>%
-      pluck("id")
-    
-  } else {
+  id <- if (input$connection_sheet_preview == "Traits")  {
     
     info$sheets %>%
       filter(name %in% input$connection_sheet_traits) %>%
       pluck("id")
     
-  }
+  } else {
+    
+    info$sheets %>%
+      filter(name %in% input$connection_sheet_fieldbook) %>%
+      pluck("id")
+  } 
   
   preview <- paste(url, id, sep = "#gid=")
   
